package jdk.internal.org.objectweb.asm.tree;

import java.util.Map;
import jdk.internal.org.objectweb.asm.Label;
import jdk.internal.org.objectweb.asm.MethodVisitor;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.List;

public class LookupSwitchInsnNode extends AbstractInsnNode
{
    public LabelNode dflt;
    public List<Integer> keys;
    public List<LabelNode> labels;
    
    public LookupSwitchInsnNode(LabelNode dflt, int[] array, LabelNode[] a) {
        super(171);
        this.dflt = dflt;
        this.keys = new ArrayList((array == null) ? 0 : array.length);
        this.labels = new ArrayList((a == null) ? 0 : a.length);
        if (array != null) {
            for (int i = 0; i < array.length; ++i) {
                this.keys.add(Integer.valueOf(array[i]));
            }
        }
        if (a != null) {
            this.labels.addAll(Arrays.asList(a));
        }
    }
    
    @Override
    public int getType() {
        return 12;
    }
    
    @Override
    public void accept(MethodVisitor methodVisitor) {
        int[] keys = new int[this.keys.size()];
        for (int i = 0; i < keys.length; ++i) {
            keys[i] = (int)this.keys.get(i);
        }
        Label[] labels = new Label[this.labels.size()];
        for (int j = 0; j < labels.length; ++j) {
            labels[j] = ((LabelNode)this.labels.get(j)).getLabel();
        }
        methodVisitor.visitLookupSwitchInsn(this.dflt.getLabel(), keys, labels);
        this.acceptAnnotations(methodVisitor);
    }
    
    @Override
    public AbstractInsnNode clone(Map<LabelNode, LabelNode> map) {
        LookupSwitchInsnNode lookupSwitchInsnNode = new LookupSwitchInsnNode(AbstractInsnNode.clone(this.dflt, map), null, AbstractInsnNode.clone(this.labels, map));
        lookupSwitchInsnNode.keys.addAll(this.keys);
        return lookupSwitchInsnNode.cloneAnnotations(this);
    }
}
